pub struct ControlPlaneAddChildRequest {
pub args: NodeAddArgs,
}Fields
args: NodeAddArgsTrait Implementations
Sourceimpl Debug for ControlPlaneAddChildRequest
impl Debug for ControlPlaneAddChildRequest
Sourceimpl Decode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for ControlPlaneAddChildRequest
impl Decode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for ControlPlaneAddChildRequest
Sourceimpl Encode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for &mut ControlPlaneAddChildRequest
impl Encode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for &mut ControlPlaneAddChildRequest
Sourceimpl<T0: Encode<NodeAddArgs, DefaultFuchsiaResourceDialect>> Encode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for (T0,)
impl<T0: Encode<NodeAddArgs, DefaultFuchsiaResourceDialect>> Encode<ControlPlaneAddChildRequest, DefaultFuchsiaResourceDialect> for (T0,)
Sourceimpl ResourceTypeMarker for ControlPlaneAddChildRequest
impl ResourceTypeMarker for ControlPlaneAddChildRequest
Sourcetype Borrowed<'a> = &'a mut ControlPlaneAddChildRequest
type Borrowed<'a> = &'a mut ControlPlaneAddChildRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &mut Self::Owned. There are three cases: Read moreSourcefn take_or_borrow<'a>(
value: &'a mut <Self as TypeMarker>::Owned,
) -> Self::Borrowed<'a>
fn take_or_borrow<'a>( value: &'a mut <Self as TypeMarker>::Owned, ) -> Self::Borrowed<'a>
Cheaply converts from
&mut Self::Owned to Self::Borrowed. For
HandleBased types this is “take” (it returns an owned handle and
replaces value with Handle::invalid), and for all other types it is
“borrow” (just converts from one reference to another).Sourceimpl TypeMarker for ControlPlaneAddChildRequest
impl TypeMarker for ControlPlaneAddChildRequest
Sourcetype Owned = ControlPlaneAddChildRequest
type Owned = ControlPlaneAddChildRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl Standalone<DefaultFuchsiaResourceDialect> for ControlPlaneAddChildRequest
impl StructuralPartialEq for ControlPlaneAddChildRequest